@@ -1,7 +1,7 @@
 # Accelerator for pip, the Python package manager.
 #
 # Author: Peter Odding <peter.odding@paylogic.eu>
-# Last Change: November 9, 2014
+# Last Change: November 15, 2014
 # URL: https://github.com/paylogic/pip-accel
 #
 # TODO Permanently store logs in the pip-accel directory (think about log rotation).
@@ -23,7 +23,7 @@ taking a look at the following functions:
 """
 
 # Semi-standard module versioning.
-__version__ = '0.14.1'
+__version__ = '0.15'
 
 # Standard library modules.
 import logging
@@ -48,7 +48,7 @@ from pip_accel.bdist import get_binary_dist, install_binary_dist
 from pip_accel.caches import CacheManager
 from pip_accel.config import binary_index, download_cache, index_version_file, on_debian, source_index
 from pip_accel.req import Requirement
-from pip_accel.utils import run
+from pip_accel.utils import makedirs, run
 
 # External dependencies.
 import coloredlogs
@@ -72,11 +72,6 @@ ENVIRONMENT = os.path.abspath(os.environ.get('VIRTUAL_ENV', sys.prefix))
 # due to connectivity issues with PyPI and/or linked distribution websites.
 MAX_RETRIES = 10
 
-# The version number of the binary distribution cache format in use. When we
-# break backwards compatibility we bump this number so that pip-accel knows it
-# should clear the cache before proceeding.
-CACHE_FORMAT_REVISION = 6
-
 def main():
     """
     Main logic of the ``pip-accel`` command.
@@ -183,7 +178,7 @@ def clear_build_directory(directory):
     logger.debug("Clearing build directory ..")
     if os.path.isdir(directory):
         shutil.rmtree(directory)
-    os.makedirs(directory)
+    makedirs(directory)
 
 def unpack_source_dists(arguments, build_directory):
     """
@@ -436,8 +431,7 @@ def initialize_directories():
     """
     # Create all required directories on the fly.
     for directory in [download_cache, source_index, binary_index]:
-        if not os.path.isdir(directory):
-            os.makedirs(directory)
+        makedirs(directory)
     # When files are removed from pip's download cache, broken symbolic links
     # remain in pip-accel's source index. This results in very confusing error
     # messages. To avoid this we cleanup broken symbolic links.
@@ -451,20 +445,9 @@ def initialize_directories():
     # download cache we can waste a lot of time. To avoid this we update the
     # symbolic links in pip-accel's source index before every run.
     update_source_dists_index()
-    # Invalidate the binary distribution cache when the
-    # format is changed in backwards incompatible ways.
+    # Cleanup the binary cache format revision marker file (no longer used).
     if os.path.isfile(index_version_file):
-        with open(index_version_file) as handle:
-            if int(handle.read()) == CACHE_FORMAT_REVISION:
-                logger.debug("Binary distribution cache format is compatible.")
-                return
-    logger.debug("Binary distribution cache format is incompatible; clearing cache ..")
-    for entry in sorted(os.listdir(binary_index)):
-        pathname = os.path.join(binary_index, entry)
-        logger.debug(" - Deleting %s.", pathname)
-        os.unlink(pathname)
-    with open(index_version_file, 'w') as handle:
-        handle.write("%i\n" % CACHE_FORMAT_REVISION)
+        os.unlink(index_version_file)
 
 ORIGINAL_PACKAGE_FINDER = None
 
